// Copyright Vrai Stacey, 2008
// $Id: birtdialog.h 1443 2008-11-03 20:10:21Z vrai $

#ifndef INC_BIRTDIALOG_H
#define INC_BIRTDIALOG_H

#include <QDialog>
#include <QHash>
#include "ui_birt.h"
#include "filelistmodel.h"
#include "transformationmodel.h"
#include "outputmodel.h"
#include "stringintbridge.h"
#include "imageresizer.h"
#include "filesearcher.h"

class ProgressDialog;
class SearchingDialog;
class ErrorsDialog;
class HelpDialog;

class BirtDialog : public QDialog
{
    Q_OBJECT

    public:
        BirtDialog ( );

    public slots:
        void reject ( );

        void processFiles ( );
        void searchDirTree ( );
        void displayHelp ( );

        // Controller methods for handling FileListView/Model actions
        void addFileToList ( );
        void removeFilesFromList ( );

        // Store dialog configuration using QSettings and restore state in the same manner
        void store ( ) const;
        void restore ( );

    protected:
        void closeEvent ( QCloseEvent * event );

        // TODO Move to own class
        StringIntBridge * getBridge ( const QString & name );
        QHash<QString, StringIntBridge *> m_bridges;

        FileListModel m_fileListModel;
        TransformationModel m_transformationModel;
        OutputModel m_outputModel;

        ProgressDialog * m_progressDialog;
        SearchingDialog * m_searchingDialog;
        ErrorsDialog * m_errorsDialog;
        HelpDialog * m_helpDialog;

        ImageResizer * m_imageResizer;
        FileSearcher * m_fileSearcher;

        QDir m_lastDirSearchRoot, m_lastOpenFileRoot;

    private:
        Ui::BirtDialog m_ui;
};

#endif

