// Copyright Vrai Stacey, 2008
// $Id: directorylineedit.cpp 1391 2008-09-14 11:58:36Z vrai $

#include "directorylineedit.h"
#include <QFileDialog>
#include <QKeyEvent>

DirectoryLineEdit::DirectoryLineEdit ( QWidget * parent )
    : QLineEdit ( parent )
{
}

void DirectoryLineEdit::browseClicked ( )
{
    // Get a directory from the user and set its path as the line edit text
    const QString directory = QFileDialog::getExistingDirectory ( this,
                                                                  tr ( "Select output directory" ),
                                                                  QDir::currentPath ( ),                // TODO Default to the currently selected directory
                                                                  QFileDialog::ShowDirsOnly );
    if ( ! directory.isEmpty ( ) )
        setText ( directory );
}

void DirectoryLineEdit::setText ( const QString & newText )
{
    // Translate changes in text to a directory change signal
    QLineEdit::setText ( newText );
    emit directoryChanged ( QDir ( text ( ) ) );
}

void DirectoryLineEdit::keyPressEvent ( QKeyEvent * event )
{
    // Translate a key press (which could change the text content) in to a directory change signal
    QLineEdit::keyPressEvent ( event );
    if ( event->isAccepted ( ) )
        emit directoryChanged ( QDir ( text ( ) ) );
}

