// Copyright Vrai Stacey, 2008
// $Id: $

#include "formatcombobox.h"
#include "imageformats.h"

FormatComboBox::FormatComboBox ( QWidget * parent )
    : QComboBox ( parent )
{
    // Populate the combo box with image format options : a null item data variant indicates that the source
    // format should be used. All the other formats are directly from the singleton.
    addItem ( tr ( "Source Format" ), QVariant ( ) );

    QStringList allFormats ( ImageFormats::instance ( ).getAllFormats ( ) );
    allFormats.sort ( );
    foreach ( const QString & format, allFormats )
        addItem ( format, format );

    // Link the generic index chnaged signal to the format specific slot
    connect ( this, SIGNAL( currentIndexChanged ( int ) ), this, SLOT( indexChanged ( int ) ) );
}

void FormatComboBox::setImageFormat ( )
{
    setImageFormat ( QVariant ( ) );
}

void FormatComboBox::setImageFormat ( const QString & format )
{
    setImageFormat ( QVariant ( format ) );
}

void FormatComboBox::setImageFormat ( const QVariant & format )
{
    const int index ( findData ( format ) );
    if ( index >= 0 )
        setCurrentIndex ( index );
}

void FormatComboBox::indexChanged ( int index )
{
    if ( itemData ( index ).isNull ( ) ) 
        emit changedFormat ( );
    else
        emit changedFormat ( itemData ( index ).toString ( ) );
}

