// Copyright Vrai Stacey, 2008
// $Id: imageresizer.h 1467 2008-11-18 21:57:44Z vrai $

#ifndef INC_IMAGERESIZER_H
#define INC_IMAGERESIZER_H

#include <QThread>
#include <QSize>
#include <QDir>
#include <QFileInfo>
#include <QHash>
#include <QPair>
#include "ratiostrategy.h"

class ImageResizer : public QObject
{
    Q_OBJECT

    public:
        ImageResizer ( QObject * parent = 0 );
        ~ImageResizer ( );

        void run ( );
        void getErrors ( QHash<QString, QString> & errors ) const;

    public slots:
        void configure ( const QSize & targetDimensions,
                         const QDir & outputDirectory,
                         const QString & prefix,
                         const QString & suffix,
                         Qt::TransformationMode scalingMode,
                         RatioStrategy::Strategy ratioStrategy,
                         int jpegQuality );
        void setFormatOverride ( const QString & format );
        void clearFiles ( );
        void addFile ( const QFileInfo & file );
        void abort ( );

    signals:
        void started ( );
        void finished ( );

        void updateCount ( int processing, int total );

    protected:
        bool m_running, m_abort;

        // Resizing options common to all files
        QSize m_targetDimensions;
        QDir m_outputDirectory;
        QString m_prefix, m_suffix;
        Qt::TransformationMode m_scalingMode;
        RatioStrategy::Strategy m_ratioStrategy;
        int m_jpegQuality;
        bool m_verboseLogging;
        QPair<bool, QString> m_format;

        // Files to be processed and error messages
        QList<QFileInfo> m_files;
        QHash<QString, QString> m_errors;
        
        QString generateNewFilename ( const QFileInfo & file, const QByteArray & sourceFormat, const QByteArray & targetFormat );
        QByteArray getOutputFormat ( const QByteArray & inputFormat );
        void resizeImage ( const QFileInfo & file );

        void addError ( const QFileInfo & file, const QString & error );
};

#endif

