// Copyright Vrai Stacey, 2008
// $Id: integerlineedit.cpp 1426 2008-10-06 19:44:41Z vrai $

#include "integerlineedit.h"
#include <QIntValidator>
#include <QKeyEvent>

IntegerLineEdit::IntegerLineEdit ( QWidget * parent )
    : QLineEdit ( parent )
{
    QIntValidator * validator ( new QIntValidator ( this ) );
    validator->setBottom ( 1 );
    setValidator ( validator );
}

void IntegerLineEdit::setInt ( int value )
{
    setText ( QString ( "%1" ).arg ( value ) );
}

void IntegerLineEdit::keyPressEvent ( QKeyEvent * event )
{
    // Create a temporary version of the new (post-keypress) text along with the insert position
    QString newText ( text ( ) + event->text ( ) );
    int position ( newText.size ( ) + event->text( ).size ( ) );

    // If there's no validator (shouldn't happen, but best to check), the key is a non-display character or (if there
    // is a validator) the validator considers the new string acceptable (not intermediate, it must be acceptable in
    // a final form - this stops leading zeros); the key press is passed on to the QLineEdit handler.
    const QValidator * theValidator ( validator ( ) );
    if ( ( ! theValidator ) || event->key ( ) < Qt::Key_Space || event->key ( ) > Qt::Key_ydiaeresis || theValidator->validate ( newText, position ) == QValidator::Acceptable )
        QLineEdit::keyPressEvent ( event );
}

