// Copyright Vrai Stacey, 2008
// $Id: ratiocombobox.cpp 1426 2008-10-06 19:44:41Z vrai $

#include "ratiocombobox.h"

RatioComboBox::RatioComboBox ( QWidget * parent )
    : QComboBox ( parent )
{
    // Populate the combo box with ratio options, linked to their strategy Ids
    addItem ( tr ( "Preserve Source Orientation" ), RatioStrategy::PreserveOrientation );
    addItem ( tr ( "Ignore Source Ratio" ),         RatioStrategy::IgnoreSource );
    addItem ( tr ( "Match New Width" ),             RatioStrategy::MatchWidth );
    addItem ( tr ( "Match New Height" ),            RatioStrategy::MatchHeight );

    // Link the generic index changed signal to the ratio specific slot
    connect ( this, SIGNAL( currentIndexChanged ( int ) ), this, SLOT( indexChanged ( int ) ) );

    // Select the first ratio (will be set to actual value by parent)
    setCurrentIndex ( 0 );
}

void RatioComboBox::setRatioStrategy ( RatioStrategy::Strategy strategy )
{
    const int index ( findData ( strategy ) );
    if ( index >= 0 )
        setCurrentIndex ( index );
}

void RatioComboBox::indexChanged ( int index )
{
    emit changedRatio ( static_cast<RatioStrategy::Strategy> ( itemData ( index ).toInt ( ) ) );
}

