// Copyright Vrai Stacey, 2008
// $Id: ratiostrategyimpl.cpp 1425 2008-10-05 17:24:36Z vrai $

#include "ratiostrategyimpl.h"

QSize IgnoreSourceRatioStrategy::operator() ( const QSize & source, const QSize & desired ) const
{
    source.width ( );       // Stops the compiler complaining about the unused parameter
    return desired;
}

QSize MatchWidthStrategy::operator() ( const QSize & source, const QSize & desired ) const
{
    double sourceWidth ( source.width ( ) ),  sourceHeight ( source.height ( ) ), desiredWidth ( desired.width ( ) );
    return QSize ( desired.width ( ), static_cast<int> ( ( desiredWidth / sourceWidth ) * sourceHeight ) );
}

QSize MatchHeightStrategy::operator() ( const QSize & source, const QSize & desired ) const
{
    double sourceWidth ( source.width ( ) ), sourceHeight ( source.height ( ) ), desiredHeight ( desired.height ( ) );
    return QSize ( static_cast<int> ( ( desiredHeight / sourceHeight ) * sourceWidth ), desired.height ( ) );
}

QSize PreserveOrientationStrategy::operator() ( const QSize & source, const QSize & desired ) const
{
    if ( source.width ( ) > source.height ( ) )
    {
        if ( desired.width ( ) > desired.height ( ) )
            return QSize ( desired.width ( ), desired.height ( ) );     // Source was landscape, desired was landscape
        else
            return QSize ( desired.height ( ), desired.width ( ) );     // Source was landscape, desired was portrait
    }
    else
    {
        if ( desired.width ( ) > desired.height ( ) )
            return QSize ( desired.height ( ), desired.width ( ) );     // Source was portrait, desired was landscape
        else
            return QSize ( desired.width ( ), desired.height ( ) );     // Source was portrait, desired was portrait
    }
}

