// Copyright Vrai Stacey, 2008
// $Id: transformationmodel.cpp 1401 2008-09-21 17:01:46Z vrai $

#include "transformationmodel.h"

TransformationModel::TransformationModel ( )
    : m_ratioStrategy ( RatioStrategy::IgnoreSource )
    , m_scalingMode ( Qt::SmoothTransformation )
{
}

TransformationModel::~TransformationModel ( )
{
}

bool TransformationModel::validate ( QStringList & errors ) const
{
    bool failed ( false );

    if ( ( failed |= ( m_dimensions.width ( ) < 1 ) ) )
        errors.append ( "Target width must be a non-zero value" );
    if ( ( failed |= ( m_dimensions.height ( ) < 1 ) ) )
        errors.append ( "Target height must be a non-zero value" );

    return ! failed;
}

const QSize & TransformationModel::getDimensions ( ) const
{
    return m_dimensions;
}

RatioStrategy::Strategy TransformationModel::getRatioStrategy ( ) const
{
    return m_ratioStrategy;
}

Qt::TransformationMode TransformationModel::getScalingMode ( ) const
{
    return m_scalingMode;
}

int TransformationModel::getJpegQuality ( ) const
{
    return m_jpegQuality;
}

void TransformationModel::changedWidth ( int width )
{
    m_dimensions.setWidth ( std::max ( 0, width ) );
}

void TransformationModel::changedHeight ( int height )
{
    m_dimensions.setHeight ( std::max ( 0, height ) );
}

void TransformationModel::changedRatioStrategy ( RatioStrategy::Strategy strategy )
{
    m_ratioStrategy = strategy;
}

void TransformationModel::changedScalingMode ( Qt::TransformationMode mode )
{
    m_scalingMode = mode;
}

void TransformationModel::changedJpegQuality ( int quality )
{
    m_jpegQuality = std::max ( 1, std::min ( 100, quality ) );
}

